import json
import traceback

from u3driver.commands.base_command import BaseCommand


class GetConstructor(BaseCommand):
    def __init__(self, socket,request_separator,request_end,type_name):
        super(GetConstructor, self).__init__(socket,request_separator,request_end)
        self.type_name = type_name
    
    def execute(self):
        data=self.send_data(self.create_command('getConstructor', self.type_name))
        data = self.handle_errors(data)
        try:
            return json.loads(data)
        except Exception as e:
            traceback.print_exc()
            return {}



from u3driver.commands.base_command import BaseCommand


class CallComponentMethod(BaseCommand):
    def __init__(self, socket,request_separator,request_end,alt_object,component_name,method_name,parameter_data):
        super(CallComponentMethod, self).__init__(socket,request_separator,request_end)
        self.alt_object=alt_object
        self.component_name = component_name
        self.method_name = method_name
        self.parameter_data = parameter_data

    def execute(self):
        data = self.send_data(self.create_command('callComponentMethod', self.alt_object, self.component_name,self.method_name,self.parameter_data))
        return self.handle_errors(data)



from u3driver.commands.base_command import BaseCommand


class GetComponent(BaseCommand):
    def __init__(self, socket,request_separator,request_end,alt_object):
        super(GetComponent, self).__init__(socket,request_separator,request_end)
        self.alt_object=alt_object

    def execute(self):
        data = self.send_data(self.create_command('getAllComponents', self.alt_object))
        return self.handle_errors(data)



import json

from u3driver.commands.base_command import BaseCommand


class GetComponentMethod(BaseCommand):
    def __init__(self, socket,request_separator,request_end,alt_object,component_name):
        super(GetComponentMethod, self).__init__(socket,request_separator,request_end)
        self.alt_object=alt_object
        self.component_name = component_name

    def execute(self):
        data = self.send_data(self.create_command('getComponentMethods', self.alt_object, self.component_name))
        return self.handle_errors(data)



import json
import traceback

from u3driver.commands.base_command import BaseCommand


class CallStaticMethod(BaseCommand):
    def __init__(self, socket,request_separator,request_end,type_name,method_name,parameter_data):
        super(CallStaticMethod, self).__init__(socket,request_separator,request_end)
        self.type_name = type_name
        self.method_name = method_name
        self.parameter_data = parameter_data
    
    def execute(self):
        data=self.send_data(self.create_command('callStaticMethod', self.type_name,self.method_name,self.parameter_data))
        return self.handle_errors(data)
